global path "YOUR PATH"
global out "$path\out"
cd "$path"

*=========================*
*===VARIABLE GENERATION===*
*=========================*

**************************
***Generate couple data***
**************************
use "2016_5%_Full.dta"   //use infix command to import the original HK census data to Stata

*dummylab*
label define dummylab 1"1 Yes" 0"0 No"

*use first line as var name*
foreach var of varlist _all {
	rename `var' `= `var'[1]'
	}

*drop the 1st obs*
drop in 1

*destring all vars*
foreach var of varlist _all {
	destring `var', replace
	}

format %25.0g QRNO	

*generate unique identifier for householdid*
gen householdid = .
recast long householdid
format %16.0g householdid
replace householdid = QRNO*100 + HHN

*generate unique identifier for person*
gen personid= .
recast long personid
format %20.0g personid
replace personid = householdid*100 + PPN

*gen spouseid*
gen spouseid = .
recast long spouseid
format %16.0g spouseid
replace spouseid = householdid*100 + SSN if SSN != 99

*seperate b/w Quarter and Person*
keep if QR_IND == 1
save "QR_info.dta"

use "2016_full.dta"
keep if QR_IND == 0
save "person_info.dta"

use "person_info.dta"

*drop admin record*
drop if PPN == 0
	
*Merge spouse activ into main dataset*
keep personid OWNER SEX AGE BORNYR MARIT BORNPL ETHNIC NAT DIST DUR_HK US_LANG OTH_LAN1 OTH_LAN2 OTH_LAN3 OTH_LAN4 SCH_ATT FIELD EDUCNH FIELDH INDUST OCCUP ACTIV MEARN OTH_EARN OCASH PPINCOM WHETWK WHETLF ALLHOUR

save "spouse_info.dta"

rename personid spouseid
format %20.0g spouseid

foreach var of varlist OWNER-ALLHOUR {
	rename `var' `var'sp
	}

label variable ACTIVsp "Spouse Activity Status"

use "person_info.dta"

merge m:1 spouseid using "spouse_info.dta", keepusing(SEXsp-OWNERsp)

keep if _merge == 3  /*only keep matched ones*/
drop _merge

save "matched_couple.dta", replace

*Only keep one household record*
bysort householdid: gen dup = _n
bysort householdid: gen dup2 = _N

keep if dup2 == 2 /*drop subdivided household 劏房戶*/
keep if dup == 1  /*keep one obs per couple*/
drop dup2 dup

*******************************************
***Calculate child number in a household***
*******************************************
*Merge CHILD15 info into the dataset*
drop CHILD15 ELDER_60 ELDER_65 ACCOM DEG_SH HHTYPE TENURE TYPEOWN RENT MORTHH YRLEFT DJHHINC RENT_INC MORT_INC ECONHH

merge 1:1 householdid using "$path\QR_info.dta", keepusing(CHILD15 ELDER_60 ELDER_65 ACCOM DEG_SH HHTYPE TENURE TYPEOWN RENT MORTHH YRLEFT DJHHINC RENT_INC MORT_INC ECONHH)

keep if _merge == 3
drop _merge

*Calculate childnumber in a hosuehold manually*
use "person_info.dta"

save "inhousechild.dta"

gen inhousechild = .
replace inhousechild = 1 if RELAT == 3
label variable inhousechild "Child of the household head"
keep if RELAT == 3

gen inhouseson = 0
replace inhouseson = 1 if SEX == 1
label variable inhouseson "Son of the household head"

gen inhousedaughter = 0
replace inhousedaughter = 1 if SEX == 2
label variable inhousedaughter "Daughter of the household head"

label val inhouseson dummylab
label val inhousedaughter dummylab

rename personid childid

save "inhousechild.dta", replace

use "person_info.dta"

save "hhead.dta", replace

keep personid householdid RELAT

keep if RELAT == 1

merge 1:m householdid using "$path\inhousechild.dta", keepusing(inhousechild inhouseson inhousedaughter childid)

save "count_child.dta", replace

drop if _merge == 2
drop _merge

sort householdid personid

bysort householdid: gen childnum = _N if inhousechild != .
replace childnum = 0 if childnum == .

egen sonnum = total(inhouseson == 1), by(householdid)
egen daughternum = total(inhousedaughter == 1), by(householdid)

label var childnum "No. of children in the HH"
label var sonnum "No. of sons in the HH"
label var daughternum "No. of daughters in the HH"

*keep one record per household*
bysort householdid: gen record = _n
keep if record == 1
save "count_child.dta", replace

*Merge child number into the dataset"
use "matched_couple.dta"

merge 1:1 householdid using "count_child.dta", keepusing(childnum sonnum daughternum)

keep if _merge == 3
drop _merge

*******************
***Dependent var***
*******************
*Whether having children*
recode CHILD15 (0=0) (1/5 =1), gen(children)
label variable children "Whether have children under 15"
label define children 0"0 No children under 15" 1"1 Have children under 15"
label val children children


************************
***Education variable***
************************
*Educational level*
gen educ_h = .
replace educ_h = EDUCNH if SEX == 1
replace educ_h = EDUCNHsp if SEXsp == 1
label var educ_h "Husband educ level"

gen educ_w = .
replace educ_w = EDUCNH if SEX == 2
replace educ_w = EDUCNHsp if SEXsp == 2
label var educ_w "Wife educ level"

recode educ_h (1 2 11/16 =1) (20/30 =2) (31/69 =3) (71/83 =4) (84/86 91 92 95 96 =5) (87/89 93 94 =6) (99 =.), gen(educat_h) /*Husband*/
label variable educat_h "Husband educ level cat"

label define edu_cat 1"1 Primary or below" 2"2 Secondary 1~4" 3"3 Secondary 5~7 & other sub-college" 4"4 First degree in college" 5"5 Master" 6"6 PhD"

label val educat_h edu_cat

recode educ_w (1 2 11/16 =1) (20/30 =2) (31/69 =3) (71/83 =4) (84/86 91 92 95 96 =5) (87/89 93 94 =6) (99 =.), gen(educat_w) /*Wife*/
label variable educat_w "Wife educ level cat"
label val educat_w edu_cat

**********************
***Demographic vars***
**********************
*Age*
gen age_h = .
replace age_h = AGE if SEX == 1
replace age_h = AGEsp if SEXsp == 1
label var age_h "Husband age"

gen age_w = .
replace age_w = AGE if SEX == 2
replace age_w = AGEsp if SEXsp == 2
label var age_w "Wife age"

*Place of birth*
recode BORNPL (1=1) (else =0), gen(BORNPL1)
recode BORNPLsp (1=1) (else =0), gen(BORNPLsp1)
gen bornpl_h = .
replace bornpl_h = BORNPL1 if SEX == 1
replace bornpl_h = BORNPLsp1 if SEXsp == 1
gen bornpl_w = .
replace bornpl_w = BORNPL1 if SEX == 2
replace bornpl_w = BORNPLsp1 if SEXsp == 2

label variable bornpl_h "Husband place of birth"
label variable bornpl_w "Wife place of birth"

label define bornpl 1"1 Hong Kong" 0"0 Outside Hong Kong"
label val bornpl_h bornpl
label val bornpl_w bornpl

*Place of birth - HK, ML, others*
gen bornpl_h2 = .
replace bornpl_h2 = BORNPL if SEX == 1
replace bornpl_h2 = BORNPLsp if SEXsp == 1
gen bornpl_w2 = .
replace bornpl_w2 = BORNPL if SEX == 2
replace bornpl_w2 = BORNPLsp if SEXsp == 2

recode bornpl_h2 (1=1) (11=2) (else=3)
recode bornpl_w2 (1=1) (11=2) (else=3)
label variable bornpl_h2 "Husband place of birth"
label variable bornpl_w2 "Wife place of birth"

label define bornpl2 1"1 Hong Kong" 2"2 Mainland" 3"3 Others"
label val bornpl_h2 bornpl2
label val bornpl_w2 bornpl2

*Ethnicity - only keep Chinese*
keep if ETHNIC == 1
keep if ETHNICsp == 1

************************
***Socioeconomic vars***
************************
*Industry*
gen indust_h = .
replace indust_h = INDUST if SEX == 1
replace indust_h = INDUSTsp if SEXsp == 1
label variable indust_h "Husband working industry"

recode indust_h (11/59 =1) (100/330 =2) (350/371 =3) (410/430 =4) (450/470 =5) (490/530 =6) (550/560 =7) (580/630 =8) (640/660 =9) (680 =10) (690/750 =11) (770/820 =12) (840 =13) (850 =14) (860/880 =15) (901/930 =16) (940/960 =17) (970 990 1 9 =18), gen(indust_h_cat)

label variable indust_h_cat "Husband working industry cat"

gen indust_w = .
replace indust_w = INDUST if SEX == 2
replace indust_w = INDUSTsp if SEXsp == 2
label variable indust_w "Wife working industry"

recode indust_w (11/59 =1) (100/330 =2) (350/371 =3) (410/430 =4) (450/470 =5) (490/530 =6) (550/560 =7) (580/630 =8) (640/660 =9) (680 =10) (690/750 =11) (770/820 =12) (840 =13) (850 =14) (860/880 =15) (901/930 =16) (940/960 =17) (970 990 1 9 =18), gen(indust_w_cat)

label variable indust_w_cat "Wife working industry cat"

*Household income*
gen lnhhinc = ln(DJHHINC + 1) if DJHHINC != 999999
label variable lnhhinc "Logged household income"

*Individual income*
*husband total*
gen income_h = .
replace income_h = PPINCOM if SEX == 1
replace income_h = PPINCOMsp if SEXsp == 1
replace income_h = 0 if income_h == 999999
label variable income_h "Husband total income"

gen lnincome_h = ln(income_h +1)
label variable lnincome_h "Husband total income log"

*wife total*
gen income_w = .
replace income_w = PPINCOM if SEX == 2
replace income_w = PPINCOMsp if SEXsp == 2
replace income_w = 0 if income_w == 999999
label variable income_w "Wife total income"

gen lnincome_w = ln(income_w +1)
label variable lnincome_w "Wife total income log"

*husband main employment*
gen income_h2 = .
replace income_h2 = MEARN if SEX == 1
replace income_h2 = MEARNsp if SEXsp == 1
replace income_h2 = 0 if income_h2 == 999999
label variable income_h2 "Husband major income"

gen lnincome_h2 = ln(income_h2 +1)
label variable lnincome_h2 "Husband major income log"

*wife main employment*
gen income_w2 = .
replace income_w2 = MEARN if SEX == 2
replace income_w2 = MEARNsp if SEXsp == 2
replace income_w2 = 0 if income_w2 == 999999
label variable income_w2 "Wife total income"

gen lnincome_w2 = ln(income_w2 +1)
label variable lnincome_w2 "Wife total income log"

*income discrepancy*
gen income_r = income_h/(income_w+1)

g inc_r = 2 if income_r > 0 & income_r < 1
replace inc_r = 3 if income_r >= 1 & income_r < 1.5
replace inc_r = 4 if income_r >= 1.5 & income_r < 2.5
replace inc_r = 5 if income_r >= 2.5 & !mi(income_r)
replace inc_r = 1 if income_h == 0
replace inc_r = 6 if income_w == 0

lab def inc_r 1 "1:Husband no income" 2 "2: Husband < Wife" 3 "3:Husband vs Wife=[1, 1.5)" 4 "4:Husband vs Wife=[1.5, 2.5)" 5 "5:Husband vs Wife >= 2.5" 6 "6:Wife no income"
lab val inc_r inc_r

*residential district*
recode DIST (2/5 =1) (6/10 =2) (11/29 30 31 91 =3), gen(residence)
label variable residence "Living district"
label define residence 1"1 HK island" 2"2 Kowloon" 3"3 NT or others"
label val residence residence

***************************
***Education Discrepancy***
***************************
gen educ_diff = educat_h - educat_w
recode educ_diff (-5/-1 = 1) (0=2) (1/5 =3), gen(educdif_cat1)
recode educ_diff (-5/-2 = 1) (-1=2) (0=3) (1=4) (2/5=5), gen(educdif_cat2)

label define dif_cat1 1"1 Husband L; Wife H" 2"2 Husband = Wife" 3"3 Husband H; Wife L"
label define dif_cat2 1"1 Husband L by 2 cat or more" 2"2 Husband low by 1 cat" 3"3 Husband = Wife" 4"4 Husband H by 1 cat" 5"5 Husband H by 2 cat or more"

label variable educdif_cat1 "Edu diff 1st measurement"
label variable educdif_cat2 "Edu diff 2nd measurement"

label val educdif_cat1 dif_cat1
label val educdif_cat2 dif_cat2


**********************
***Child num recode***
**********************
*Regroup those with 4 children or more*
recode childnum (4 5 6 = 4), gen(childnum_trun)

*Generate whether have children var*
recode childnum (0 = 0) (else = 1), gen(havechild)
label var havechild "Have children at home"
label val havechild dummylab

*=====================*
*===DRM REGRESSIONs===*
*=====================*
use "matched_couple.dta"

*No of children*
/*1st measure edu diff*/
global cov lnhhinc ib3.inc_r lnincome_h lnincome_w age_h age_w i.bornpl_h2 i.bornpl_w2 i.residence i.indust_h_cat i.indust_w_cat

*Figure 2*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=35 & age_w<=52, intervars(educdif_cat1) vce(robust) 
ta educat_h educat_w if e(sample)
*Husband's educational attainment*
twoway histogram educat_h if e(sample), percent width(0.5) discrete  ///
ytitle("{stSerif: Percentage}", size(medsmall)) ///
xtitle("{stSerif: Husband's educational attainment}", size(medsmall))   ///
ylabel(0(10)50, format(%5.0f) labsize(small)) ///
xlabel(1 "{stSerif: Primary & below}" 2 "{stSerif: Secondary 1~4}" 3 "{stSerif: Secondary 5~7/sub-college}" 4 "{stSerif: Bachelor}" 5 "{stSerif: Master}" 6 "{stSerif: PhD}", labsize(vsmall))     ///
scheme(s1mono)    ///
saving(husband)
cd "$out"
graph export husband_edu.png, replace

*Wife's educational attainment*
twoway histogram educat_w if e(sample), percent width(0.5) discrete  ///
ytitle("{stSerif: Percentage}", size(medsmall)) ///
xtitle("{stSerif: Wife's educational attainment}", size(medsmall))   ///
ylabel(0(10)50, format(%5.0f) labsize(small)) ///
xlabel(1 "{stSerif: Primary & below}" 2 "{stSerif: Secondary 1~4}" 3 "{stSerif: Secondary 5~7/sub-college}" 4 "{stSerif: Bachelor}" 5 "{stSerif: Master}" 6 "{stSerif: PhD}", labsize(vsmall))     ///
scheme(s1mono)    ///
saving(wife)
cd "$out"
graph export wife_edu.png, replace

*Combine two graphs to generate Figure 2*
gr combine husband.gph wife.gph


*Table 3*
*Model 3.1*
drm havechild educat_h educat_w $cov if age_w>=35 & age_w<=52, link(logit) vce(robust) 

outreg2 using no_discrep.xls, dec(2) replace

*Model 3.2*
drm childnum_trun educat_h educat_w $cov if age_w>=35 & age_w<=52 & childnum_trun>0, link(linear) vce(robust) 
outreg2 using no-discrep.xls, dec(2) replace

*Table 4 - interactive p value*
*Model 4.1*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov if age_w>=35 & age_w<=52, intervars(educdif_cat1) link(logit) vce(robust) 
*Model 4.2*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=35 & age_w<=52 & childnum_trun>0, intervars(educdif_cat1) link(linear) vce(robust) 

lincom (_b[p:_cons])+(_b[rho:educdif_cat1]*1)		/*Husband L Wife H(p)*/
lincom 1-(_b[p:_cons]+_b[rho:educdif_cat1]*1)		/*Husband L Wife H(q)*/

lincom (_b[p:_cons])+(_b[rho:educdif_cat1]*2)		/*Husband = Wife (p)*/
lincom 1-(_b[p:_cons]+_b[rho:educdif_cat1]*2)		/*Husband = Wife(q)*/

lincom (_b[p:_cons])+(_b[rho:educdif_cat1]*3)   	/*Husband H Wife L(p)*/
lincom 1-(_b[p:_cons]+_b[rho:educdif_cat1]*3)   	/*Husband H Wife L(q)*/

*Table 5*
*Model 5.1*
drm havechild educat_h educat_w ib3.educdif_cat2 $cov if age_w>=35 & age_w<=52, link(logit) vce(robust) 
*Model 5.2*
drm childnum_trun educat_h educat_w ib3.educdif_cat2 $cov if age_w>=35 & age_w<=52 & childnum_trun>0, vce(robust) 


*==========================*
*===OLS Regression===*
*==========================*
*Check whether asso b/w edu & fertility is the same for both genders*
*Model B1.1*
reg havechild i.educat_h i.educat_w $cov if age_w>=35 & age_w<=52, vce(robust)    
*Model B1.2*
reg childnum_trun i.educat_h i.educat_w $cov if age_w>=35 & age_w<=52 & childnum_trun>0, vce(robust) 


*========================*
*===SUBSAMPLE ANALYSIS===*
*========================*
*Table C1*
*35-45*
*C3.1.1*
drm havechild educat_h educat_w $cov if age_w>=35 & age_w<=45, link(logit) vce(robust) 
lincom (_b[p:_cons])-(_b[q:_cons])
*C3.2.1*
drm childnum_trun educat_h educat_w $cov if age_w>=35 & age_w<=45 & childnum_trun>0, link(linear) vce(robust) 

*38-48*
*C3.1.2*
drm havechild educat_h educat_w $cov if age_w>=38 & age_w<=48, link(logit) vce(robust) 
lincom (_b[p:_cons])-(_b[q:_cons]) 
*C3.2.2*
drm childnum_trun educat_h educat_w $cov if age_w>=38 & age_w<=48 & childnum_trun>0, link(linear) vce(robust) 
lincom (_b[p:_cons])-(_b[q:_cons]) 

*40-50*
*C3.1.3*
drm havechild educat_h educat_w $cov if age_w>=40 & age_w<=50, link(logit) vce(robust) 
lincom (_b[p:_cons])-(_b[q:_cons]) 
*C3.2.3*
drm childnum_trun educat_h educat_w $cov if age_w>=40 & age_w<=50 & childnum_trun>0, link(linear) vce(robust) 
lincom (_b[p:_cons])-(_b[q:_cons]) 

*42-52*
*C3.1.4*
drm havechild educat_h educat_w $cov if age_w>=42 & age_w<=52, link(logit) vce(robust) 
*C3.2.4*
drm childnum_trun educat_h educat_w $cov if age_w>=42 & age_w<=52 & childnum_trun>0, link(linear) vce(robust) 
lincom (_b[p:_cons])-(_b[q:_cons]) 

*Table C2*
*35-45*
*C4.1.1*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov if age_w>=35 & age_w<=45, intervars(educdif_cat1) link(logit) vce(robust) 
*C4.2.1*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=35 & age_w<=45 & childnum_trun>0, intervars(educdif_cat1) link(linear) vce(robust) 

*38-48*
*C4.1.2*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov if age_w>=38 & age_w<=48, intervars(educdif_cat1) link(logit) vce(robust) 
*C4.2.2*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=38 & age_w<=48 & childnum_trun>0, intervars(educdif_cat1) link(linear) vce(robust) 

*40-50*
*C4.1.3*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov if age_w>=40 & age_w<=50, intervars(educdif_cat1) link(logit) vce(robust) 
*C4.2.3*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=40 & age_w<=50 & childnum_trun>0, intervars(educdif_cat1) link(linear) vce(robust) 

*42-52*
*C4.1.4*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov if age_w>=42 & age_w<=52, intervars(educdif_cat1) link(logit) vce(robust) 
*C4.2.4*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=42 & age_w<=52 & childnum_trun>0, intervars(educdif_cat1) link(linear) vce(robust) 

*P & Q difference*
*p1-q1*
lincom (_b[p:_cons])+(_b[rho:educdif_cat1]*1) - [1-(_b[p:_cons]+_b[rho:educdif_cat1]*1)]
*p2-q2*
lincom (_b[p:_cons])+(_b[rho:educdif_cat1]*2) -[1-(_b[p:_cons]+_b[rho:educdif_cat1]*2)]
*p3-q3*
lincom (_b[p:_cons])+(_b[rho:educdif_cat1]*3) -[1-(_b[p:_cons]+_b[rho:educdif_cat1]*3) ]

*Test whether change in p or q is significant*
*p2-p1*
lincom _b[rho:educdif_cat1]   //p2-p1
lincom -_b[rho:educdif_cat1]   //q2-q1
*p3-p2*
lincom _b[rho:educdif_cat1]   //p3-p2
lincom -_b[rho:educdif_cat1]   //q3-q2
*p3-p1*
lincom 2*[rho]educdif_cat1   //p3-p1

*Table C3*
*35~45 yrs old*
*C5.1.1*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov  if age_w>=35 & age_w<=45, link(probit) vce(robust) 
*C5.2.1*
drm havechild educat_h educat_w ib3.educdif_cat2 $cov if age_w>=35 & age_w<=45, link(logit) vce(robust) 
*C5.3.1*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=35 & age_w<=45 & childnum_trun>0, vce(robust) 
*C5.4.1*
drm childnum_trun educat_h educat_w ib3.educdif_cat2 $cov if age_w>=35 & age_w<=45 & childnum_trun>0, vce(robust) 

*38~48 yrs old*
*C5.1.2*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov  if age_w>=38 & age_w<=48, link(probit) vce(robust) 
*C5.2.2*
drm havechild educat_h educat_w ib3.educdif_cat2 $cov if age_w>=38 & age_w<=48, link(logit) vce(robust) 
*C5.3.2*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=38 & age_w<=48 & childnum_trun>0, vce(robust) 
*C5.4.2*
drm childnum_trun educat_h educat_w ib3.educdif_cat2 $cov if age_w>=38 & age_w<=48 & childnum_trun>0, vce(robust) 

*40~50 yrs old*
*C5.1.3*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov  if age_w>=40 & age_w<=50, link(probit) vce(robust) 
*C5.2.3*
drm havechild educat_h educat_w ib3.educdif_cat2 $cov if age_w>=40 & age_w<=50, link(logit) vce(robust) 
*C5.3.3*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=40 & age_w<=50 & childnum_trun>0, vce(robust) 
*C5.4.3*
drm childnum_trun educat_h educat_w ib3.educdif_cat2 $cov if age_w>=40 & age_w<=50 & childnum_trun>0, vce(robust) 

*42~52 yrs old*
*C5.1.4*
drm havechild educat_h educat_w ib2.educdif_cat1 $cov  if age_w>=42 & age_w<=52, link(probit) vce(robust) 
*C5.2.4*
drm havechild educat_h educat_w ib3.educdif_cat2 $cov if age_w>=42 & age_w<=52, link(logit) vce(robust) 
*C5.3.4*
drm childnum_trun educat_h educat_w ib2.educdif_cat1 $cov if age_w>=42 & age_w<=52 & childnum_trun>0, vce(robust) 
*C5.4.4*
drm childnum_trun educat_h educat_w ib3.educdif_cat2 $cov if age_w>=42 & age_w<=52 & childnum_trun>0, vce(robust) 

























